# Matching

Utilities for comparing and partitioning named dimension tuples,
including wildcard/ellipsis support.

::: torchlinops.nameddim.isequal

::: torchlinops.nameddim.iscompatible

::: torchlinops.nameddim.partition
